# Testing

## Browser

It uses [playwright](https://playwright.dev/python/) to test the built documentation site against a browser.

> [!IMPORTANT]
> Chromium must be installed
> ```shell
> uv run playwright install chromium
> ```
